Revert "Revert adoption of CUDA indexing in general - this can only work with later versions of the compiler, just like module based dispatch, and thus must be guarded against usage in earlier (e.g. 1.6) versions."
This reverts commit d2fd1f5
This commit is contained in:
@@ -2,7 +2,7 @@
|
||||
#include "hip/hip_runtime_api.h"
|
||||
|
||||
__global__ void Kernel(hipLaunchParm lp, float *Ad){
|
||||
int tx = threadIdx.x + blockIdx.x * blockDim.x;
|
||||
int tx = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
|
||||
Ad[tx] += Ad[tx-1];
|
||||
}
|
||||
|
||||
|
||||
Fai riferimento in un nuovo problema
Block a user